@@ -7,7 +7,7 @@ use Mite::Miteception -all;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007003';
+our $VERSION   = '0.007004';
 
 use Path::Tiny;
 use mro;
@@ -292,7 +292,8 @@ sub _compile_new {
     my $self = shift;
     my @vars = ('$class', '$self', '$args', '$meta');
 
-    return sprintf <<'CODE', $self->_compile_meta(@vars), $self->_compile_bless(@vars), $self->_compile_buildargs(@vars), $self->_compile_init_attributes(@vars), $self->_compile_strict_constructor(@vars), $self->_compile_buildall(@vars, '$no_build');
+    return sprintf <<'CODE', $self->_compile_meta(@vars), $self->_compile_bless(@vars), $self->_compile_buildargs(@vars), $self->_compile_init_attributes(@vars), $self->_compile_buildall(@vars, '$no_build'), $self->_compile_strict_constructor(@vars);
+# Standard Moose/Moo-style constructor
 sub new {
     my $class = ref($_[0]) ? ref(shift) : shift;
     my $meta  = %s;
@@ -302,10 +303,10 @@ sub new {
 
 %s
 
-    # Enforce strict constructor
+    # Call BUILD methods
     %s
 
-    # Call BUILD methods
+    # Unrecognized parameters
     %s
 
     return $self;
@@ -387,6 +388,7 @@ sub _compile_buildall_method {
     my $self = shift;
 
     return sprintf <<'CODE', $self->_compile_meta( '$class', '$_[0]', '$_[1]', '$meta' ),
+# Used by constructor to call BUILD methods
 sub BUILDALL {
     my $class = ref( $_[0] );
     my $meta  = %s;
@@ -398,6 +400,7 @@ CODE
 sub _compile_destroy {
     my $self = shift;
     sprintf <<'CODE', $self->_compile_meta( '$class', '$self' );
+# Destructor should call DEMOLISH methods
 sub DESTROY {
     my $self  = shift;
     my $class = ref( $self ) || $self;
@@ -443,7 +446,8 @@ sub _compile_init_attributes {
         my $guard = $attr->locally_set_compiling_class( $self );
         my @lines = grep !!$_, $attr->compile_init( $selfvar, $argvar );
         if ( @lines ) {
-            push @code, sprintf "# Attribute: %s", $attr->name;
+            push @code, sprintf "# Attribute %s%s",
+               $attr->name, $attr->type ? sprintf( ' (type: %s)', $attr->type->display_name ) : '';
             push @code, @lines;
             push @code, '';
         }
